aboutsummaryrefslogtreecommitdiffstats
path: root/os/rt/include/chthreads.h
diff options
context:
space:
mode:
Diffstat (limited to 'os/rt/include/chthreads.h')
-rw-r--r--os/rt/include/chthreads.h11
1 files changed, 7 insertions, 4 deletions
diff --git a/os/rt/include/chthreads.h b/os/rt/include/chthreads.h
index 47d7c2672..1b29260ed 100644
--- a/os/rt/include/chthreads.h
+++ b/os/rt/include/chthreads.h
@@ -307,18 +307,21 @@ static inline systime_t chThdGetTicksX(thread_t *tp) {
}
#endif
+#if (CH_DBG_ENABLE_STACK_CHECK == TRUE) || (CH_CFG_USE_DYNAMIC == TRUE) || \
+ defined(__DOXYGEN__)
/**
* @brief Returns the stack limit of the specified thread.
*
* @param[in] tp pointer to the thread
- * @return The stack limit pointer.
+ * @return The working area base pointer.
*
* @xclass
*/
-static inline stkalign_t *chthdGetStackLimitX(thread_t *tp) {
+static inline stkalign_t *chThdGetWorkingAreaX(thread_t *tp) {
- return tp->stklimit;
+ return tp->wabase;
}
+#endif /* CH_DBG_ENABLE_STACK_CHECK == TRUE */
/**
* @brief Verifies if the specified thread is in the @p CH_STATE_FINAL state.
@@ -307,18 +307,21 @@ static inline systime_t chThdGetTicksX(thread_t *tp) {
/**
- * @brief Returns the stack limit of the specified thread.
+ * @brief Returns the working area base of the specified thread.
*
* @param[in] tp pointer to the thread